"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ensureCorrectChoiceKeys = exports.getChoiceTextByKey = exports.getChoiceKeysFromChoices = exports.choicesIsMap = exports.choicesIsArray = void 0;
function choicesIsArray(choices) {
    return Array.isArray(choices);
}
exports.choicesIsArray = choicesIsArray;
function choicesIsMap(choices) {
    return choices instanceof Map;
}
exports.choicesIsMap = choicesIsMap;
function getChoiceKeysFromChoices(choices) {
    if (choicesIsArray(choices)) {
        return choices.map(String);
    }
    if (choicesIsMap(choices)) {
        return [...choices.keys()].map(String);
    }
    return Object.keys(choices);
}
exports.getChoiceKeysFromChoices = getChoiceKeysFromChoices;
function getChoiceTextByKey(choices, key) {
    if (choicesIsArray(choices)) {
        return key;
    }
    if (choicesIsMap(choices)) {
        return choices.get(key) ?? key;
    }
    const choice = choices[key];
    if (choice) {
        return choice;
    }
    return key;
}
exports.getChoiceTextByKey = getChoiceTextByKey;
function ensureCorrectChoiceKeys(actionPrefix, path, choiceKeys) {
    const containSlashExample = choiceKeys.find(o => o.includes('/'));
    if (containSlashExample) {
        throw new Error(`Choices can not contain '/'. Found '${containSlashExample}' in action '${actionPrefix}' at path '${path}'.`);
    }
}
exports.ensureCorrectChoiceKeys = ensureCorrectChoiceKeys;
//# sourceMappingURL=understand-choices.js.map